==> zio-aws-codebuild_3-5.17.148.1-sources.jar: zio/aws/codebuild/model/ListReportsResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListReportsResponse(
    nextToken: Option[String] = None,
    reports: Option[Iterable[NonEmptyString]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListReportsResponse = {
    import ListReportsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListReportsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        reports.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.reports)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.ListReportsResponse.ReadOnly =
    zio.aws.codebuild.model.ListReportsResponse.wrap(buildAwsValue())
}
object ListReportsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListReportsResponse =
      zio.aws.codebuild.model.ListReportsResponse(
        nextToken.map(value => value),
        reports.map(value => value)
      )
    def nextToken: Option[String]
    def reports: Option[List[NonEmptyString]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getReports: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("reports", reports)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ) extends zio.aws.codebuild.model.ListReportsResponse.ReadOnly {
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val reports: Option[List[NonEmptyString]] = scala
      .Option(impl.reports())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ): zio.aws.codebuild.model.ListReportsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-codebuild_3-5.17.295.22-sources.jar: zio/aws/codebuild/model/ListReportsResponse.scala <==
package zio.aws.codebuild.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.codebuild.model.primitives.NonEmptyString
import scala.jdk.CollectionConverters.*
final case class ListReportsResponse(
    nextToken: Optional[String] = Optional.Absent,
    reports: Optional[Iterable[NonEmptyString]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codebuild.model.ListReportsResponse = {
    import ListReportsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codebuild.model.ListReportsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        reports.map(value =>
          value.map { item =>
            NonEmptyString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.reports)
      .build()
  }
  def asReadOnly: zio.aws.codebuild.model.ListReportsResponse.ReadOnly =
    zio.aws.codebuild.model.ListReportsResponse.wrap(buildAwsValue())
}
object ListReportsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codebuild.model.ListReportsResponse =
      zio.aws.codebuild.model.ListReportsResponse(
        nextToken.map(value => value),
        reports.map(value => value)
      )
    def nextToken: Optional[String]
    def reports: Optional[List[NonEmptyString]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getReports: ZIO[Any, AwsError, List[NonEmptyString]] =
      AwsError.unwrapOptionField("reports", reports)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ) extends zio.aws.codebuild.model.ListReportsResponse.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val reports: Optional[List[NonEmptyString]] = zio.aws.core.internal
      .optionalFromNullable(impl.reports())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.codebuild.model.primitives.NonEmptyString(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.codebuild.model.ListReportsResponse
  ): zio.aws.codebuild.model.ListReportsResponse.ReadOnly = new Wrapper(impl)
}
